@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Render;
 
-our $VERSION = '0.033'; # VERSION
+our $VERSION = '0.034'; # VERSION
 
 use constant TRACE => $ENV{YAML_PP_TRACE} ? 1 : 0;
 
@@ -71,6 +71,13 @@ sub render_block_scalar {
     if ($folded) {
 
         my $prev = 'START';
+        my $trailing = '';
+        if ($keep) {
+            while (@$lines and $lines->[-1] eq '') {
+                pop @$lines;
+                $trailing .= "\n";
+            }
+        }
         for my $i (0 .. $#$lines) {
             my $line = $lines->[ $i ];
 
@@ -107,6 +114,9 @@ sub render_block_scalar {
 
             $prev = $type;
         }
+        if ($keep) {
+            $string .= $trailing;
+        }
         $string .= "\n" if @$lines and not $trim;
     }
     else {
