@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Representer;
 
-our $VERSION = '0.033'; # VERSION
+our $VERSION = '0.034'; # VERSION
 
 use Scalar::Util qw/ reftype blessed refaddr /;
 
@@ -69,10 +69,10 @@ sub represent_node {
     }
 
     if ($node->{reftype}) {
-        $self->represent_noderef($node);
+        $self->_represent_noderef($node);
     }
     else {
-        $self->represent_node_nonref($node);
+        $self->_represent_node_nonref($node);
     }
     $node->{reftype} = (reftype $node->{data}) || '';
 
@@ -131,7 +131,16 @@ sub represent_node {
 
 }
 
-sub represent_node_nonref {
+my $bool_code = <<'EOM';
+sub {
+    my ($x) = @_;
+    use experimental qw/ builtin /;
+    builtin::is_bool($x);
+}
+EOM
+my $is_bool;
+
+sub _represent_node_nonref {
     my ($self, $node) = @_;
     my $representers = $self->schema->representers;
 
@@ -145,6 +154,12 @@ sub represent_node_nonref {
             return 1;
         }
     }
+    if ($] >= 5.036000 and my $rep = $representers->{bool}) {
+        $is_bool ||= eval $bool_code;
+        if ($is_bool->($node->{value})) {
+            return $rep->{code}->($self, $node);
+        }
+    }
     for my $rep (@{ $representers->{flags} }) {
         my $check_flags = $rep->{flags};
         my $flags = B::svref_2object(\$node->{value})->FLAGS;
@@ -170,7 +185,7 @@ sub represent_node_nonref {
     }
 }
 
-sub represent_noderef {
+sub _represent_noderef {
     my ($self, $node) = @_;
     my $representers = $self->schema->representers;
 
